# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.list_targets_output import ListTargetsOutput  # noqa: E501
from akeyless.rest import ApiException

class TestListTargetsOutput(unittest.TestCase):
    """ListTargetsOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListTargetsOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.list_targets_output.ListTargetsOutput()  # noqa: E501
        if include_optional :
            return ListTargetsOutput(
                next_page = '0', 
                targets = [
                    akeyless.models.target_includes_target_details/.Target includes target details.(
                        comment = '0', 
                        protection_key_name = '0', 
                        target_id = 56, 
                        target_items_assoc = [
                            akeyless.models.target_item_association.TargetItemAssociation(
                                assoc_id = '0', 
                                item_name = '0', )
                            ], 
                        target_name = '0', 
                        target_type = '0', 
                        with_customer_fragment = True, )
                    ]
            )
        else :
            return ListTargetsOutput(
        )

    def testListTargetsOutput(self):
        """Test ListTargetsOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Connect(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'helper': 'object',
        'rc_file_override': 'str',
        'bastion_ctrl_path': 'str',
        'bastion_ctrl_port': 'str',
        'bastion_ctrl_proto': 'str',
        'bastion_ctrl_subdomain': 'str',
        'cert_issuer_name': 'str',
        'identity_file': 'str',
        'json': 'bool',
        'name': 'str',
        'ssh_command': 'str',
        'ssh_extra_args': 'str',
        'ssh_legacy_signing_alg': 'bool',
        'target': 'str',
        'token': 'str',
        'uid_token': 'str',
        'via_bastion': 'str'
    }

    attribute_map = {
        'helper': 'Helper',
        'rc_file_override': 'RcFileOverride',
        'bastion_ctrl_path': 'bastion-ctrl-path',
        'bastion_ctrl_port': 'bastion-ctrl-port',
        'bastion_ctrl_proto': 'bastion-ctrl-proto',
        'bastion_ctrl_subdomain': 'bastion-ctrl-subdomain',
        'cert_issuer_name': 'cert-issuer-name',
        'identity_file': 'identity-file',
        'json': 'json',
        'name': 'name',
        'ssh_command': 'ssh-command',
        'ssh_extra_args': 'ssh-extra-args',
        'ssh_legacy_signing_alg': 'ssh-legacy-signing-alg',
        'target': 'target',
        'token': 'token',
        'uid_token': 'uid-token',
        'via_bastion': 'via-bastion'
    }

    def __init__(self, helper=None, rc_file_override=None, bastion_ctrl_path=None, bastion_ctrl_port='9900', bastion_ctrl_proto='http', bastion_ctrl_subdomain=None, cert_issuer_name=None, identity_file=None, json=None, name=None, ssh_command=None, ssh_extra_args=None, ssh_legacy_signing_alg=None, target=None, token=None, uid_token=None, via_bastion=None, local_vars_configuration=None):  # noqa: E501
        """Connect - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._helper = None
        self._rc_file_override = None
        self._bastion_ctrl_path = None
        self._bastion_ctrl_port = None
        self._bastion_ctrl_proto = None
        self._bastion_ctrl_subdomain = None
        self._cert_issuer_name = None
        self._identity_file = None
        self._json = None
        self._name = None
        self._ssh_command = None
        self._ssh_extra_args = None
        self._ssh_legacy_signing_alg = None
        self._target = None
        self._token = None
        self._uid_token = None
        self._via_bastion = None
        self.discriminator = None

        if helper is not None:
            self.helper = helper
        if rc_file_override is not None:
            self.rc_file_override = rc_file_override
        if bastion_ctrl_path is not None:
            self.bastion_ctrl_path = bastion_ctrl_path
        if bastion_ctrl_port is not None:
            self.bastion_ctrl_port = bastion_ctrl_port
        if bastion_ctrl_proto is not None:
            self.bastion_ctrl_proto = bastion_ctrl_proto
        if bastion_ctrl_subdomain is not None:
            self.bastion_ctrl_subdomain = bastion_ctrl_subdomain
        if cert_issuer_name is not None:
            self.cert_issuer_name = cert_issuer_name
        if identity_file is not None:
            self.identity_file = identity_file
        if json is not None:
            self.json = json
        if name is not None:
            self.name = name
        if ssh_command is not None:
            self.ssh_command = ssh_command
        if ssh_extra_args is not None:
            self.ssh_extra_args = ssh_extra_args
        if ssh_legacy_signing_alg is not None:
            self.ssh_legacy_signing_alg = ssh_legacy_signing_alg
        if target is not None:
            self.target = target
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if via_bastion is not None:
            self.via_bastion = via_bastion

    @property
    def helper(self):
        """Gets the helper of this Connect.  # noqa: E501


        :return: The helper of this Connect.  # noqa: E501
        :rtype: object
        """
        return self._helper

    @helper.setter
    def helper(self, helper):
        """Sets the helper of this Connect.


        :param helper: The helper of this Connect.  # noqa: E501
        :type: object
        """

        self._helper = helper

    @property
    def rc_file_override(self):
        """Gets the rc_file_override of this Connect.  # noqa: E501

        used to override .akeyless-connect.rc in tests  # noqa: E501

        :return: The rc_file_override of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._rc_file_override

    @rc_file_override.setter
    def rc_file_override(self, rc_file_override):
        """Sets the rc_file_override of this Connect.

        used to override .akeyless-connect.rc in tests  # noqa: E501

        :param rc_file_override: The rc_file_override of this Connect.  # noqa: E501
        :type: str
        """

        self._rc_file_override = rc_file_override

    @property
    def bastion_ctrl_path(self):
        """Gets the bastion_ctrl_path of this Connect.  # noqa: E501

        The Bastion API path  # noqa: E501

        :return: The bastion_ctrl_path of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._bastion_ctrl_path

    @bastion_ctrl_path.setter
    def bastion_ctrl_path(self, bastion_ctrl_path):
        """Sets the bastion_ctrl_path of this Connect.

        The Bastion API path  # noqa: E501

        :param bastion_ctrl_path: The bastion_ctrl_path of this Connect.  # noqa: E501
        :type: str
        """

        self._bastion_ctrl_path = bastion_ctrl_path

    @property
    def bastion_ctrl_port(self):
        """Gets the bastion_ctrl_port of this Connect.  # noqa: E501

        The Bastion API Port  # noqa: E501

        :return: The bastion_ctrl_port of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._bastion_ctrl_port

    @bastion_ctrl_port.setter
    def bastion_ctrl_port(self, bastion_ctrl_port):
        """Sets the bastion_ctrl_port of this Connect.

        The Bastion API Port  # noqa: E501

        :param bastion_ctrl_port: The bastion_ctrl_port of this Connect.  # noqa: E501
        :type: str
        """

        self._bastion_ctrl_port = bastion_ctrl_port

    @property
    def bastion_ctrl_proto(self):
        """Gets the bastion_ctrl_proto of this Connect.  # noqa: E501

        The Bastion API protocol  # noqa: E501

        :return: The bastion_ctrl_proto of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._bastion_ctrl_proto

    @bastion_ctrl_proto.setter
    def bastion_ctrl_proto(self, bastion_ctrl_proto):
        """Sets the bastion_ctrl_proto of this Connect.

        The Bastion API protocol  # noqa: E501

        :param bastion_ctrl_proto: The bastion_ctrl_proto of this Connect.  # noqa: E501
        :type: str
        """

        self._bastion_ctrl_proto = bastion_ctrl_proto

    @property
    def bastion_ctrl_subdomain(self):
        """Gets the bastion_ctrl_subdomain of this Connect.  # noqa: E501

        The Bastion API prefix  # noqa: E501

        :return: The bastion_ctrl_subdomain of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._bastion_ctrl_subdomain

    @bastion_ctrl_subdomain.setter
    def bastion_ctrl_subdomain(self, bastion_ctrl_subdomain):
        """Sets the bastion_ctrl_subdomain of this Connect.

        The Bastion API prefix  # noqa: E501

        :param bastion_ctrl_subdomain: The bastion_ctrl_subdomain of this Connect.  # noqa: E501
        :type: str
        """

        self._bastion_ctrl_subdomain = bastion_ctrl_subdomain

    @property
    def cert_issuer_name(self):
        """Gets the cert_issuer_name of this Connect.  # noqa: E501

        The Akeyless certificate issuer name  # noqa: E501

        :return: The cert_issuer_name of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._cert_issuer_name

    @cert_issuer_name.setter
    def cert_issuer_name(self, cert_issuer_name):
        """Sets the cert_issuer_name of this Connect.

        The Akeyless certificate issuer name  # noqa: E501

        :param cert_issuer_name: The cert_issuer_name of this Connect.  # noqa: E501
        :type: str
        """

        self._cert_issuer_name = cert_issuer_name

    @property
    def identity_file(self):
        """Gets the identity_file of this Connect.  # noqa: E501

        The file from which the identity (private key) for public key authentication is read  # noqa: E501

        :return: The identity_file of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._identity_file

    @identity_file.setter
    def identity_file(self, identity_file):
        """Sets the identity_file of this Connect.

        The file from which the identity (private key) for public key authentication is read  # noqa: E501

        :param identity_file: The identity_file of this Connect.  # noqa: E501
        :type: str
        """

        self._identity_file = identity_file

    @property
    def json(self):
        """Gets the json of this Connect.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this Connect.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this Connect.

        Set output format to JSON  # noqa: E501

        :param json: The json of this Connect.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this Connect.  # noqa: E501

        The Secret name (for database and AWS producers - producer name)  # noqa: E501

        :return: The name of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Connect.

        The Secret name (for database and AWS producers - producer name)  # noqa: E501

        :param name: The name of this Connect.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def ssh_command(self):
        """Gets the ssh_command of this Connect.  # noqa: E501

        Path to SSH executable. e.g. /usr/bin/ssh  # noqa: E501

        :return: The ssh_command of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._ssh_command

    @ssh_command.setter
    def ssh_command(self, ssh_command):
        """Sets the ssh_command of this Connect.

        Path to SSH executable. e.g. /usr/bin/ssh  # noqa: E501

        :param ssh_command: The ssh_command of this Connect.  # noqa: E501
        :type: str
        """

        self._ssh_command = ssh_command

    @property
    def ssh_extra_args(self):
        """Gets the ssh_extra_args of this Connect.  # noqa: E501

        The Use to add offical SSH arguments (except -i)  # noqa: E501

        :return: The ssh_extra_args of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._ssh_extra_args

    @ssh_extra_args.setter
    def ssh_extra_args(self, ssh_extra_args):
        """Sets the ssh_extra_args of this Connect.

        The Use to add offical SSH arguments (except -i)  # noqa: E501

        :param ssh_extra_args: The ssh_extra_args of this Connect.  # noqa: E501
        :type: str
        """

        self._ssh_extra_args = ssh_extra_args

    @property
    def ssh_legacy_signing_alg(self):
        """Gets the ssh_legacy_signing_alg of this Connect.  # noqa: E501

        Set this option to output legacy ('ssh-rsa-cert-v01@openssh.com') signing algorithm name in the ssh certificate.  # noqa: E501

        :return: The ssh_legacy_signing_alg of this Connect.  # noqa: E501
        :rtype: bool
        """
        return self._ssh_legacy_signing_alg

    @ssh_legacy_signing_alg.setter
    def ssh_legacy_signing_alg(self, ssh_legacy_signing_alg):
        """Sets the ssh_legacy_signing_alg of this Connect.

        Set this option to output legacy ('ssh-rsa-cert-v01@openssh.com') signing algorithm name in the ssh certificate.  # noqa: E501

        :param ssh_legacy_signing_alg: The ssh_legacy_signing_alg of this Connect.  # noqa: E501
        :type: bool
        """

        self._ssh_legacy_signing_alg = ssh_legacy_signing_alg

    @property
    def target(self):
        """Gets the target of this Connect.  # noqa: E501

        The target  # noqa: E501

        :return: The target of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Connect.

        The target  # noqa: E501

        :param target: The target of this Connect.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def token(self):
        """Gets the token of this Connect.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Connect.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this Connect.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this Connect.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this Connect.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this Connect.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def via_bastion(self):
        """Gets the via_bastion of this Connect.  # noqa: E501

        The jump box server  # noqa: E501

        :return: The via_bastion of this Connect.  # noqa: E501
        :rtype: str
        """
        return self._via_bastion

    @via_bastion.setter
    def via_bastion(self, via_bastion):
        """Sets the via_bastion of this Connect.

        The jump box server  # noqa: E501

        :param via_bastion: The via_bastion of this Connect.  # noqa: E501
        :type: str
        """

        self._via_bastion = via_bastion

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Connect):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Connect):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Role(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_date': 'datetime',
        'client_permissions': 'list[str]',
        'comment': 'str',
        'creation_date': 'datetime',
        'modification_date': 'datetime',
        'role_auth_methods_assoc': 'list[RoleAuthMethodAssociation]',
        'role_name': 'str',
        'rules': 'Rules'
    }

    attribute_map = {
        'access_date': 'access_date',
        'client_permissions': 'client_permissions',
        'comment': 'comment',
        'creation_date': 'creation_date',
        'modification_date': 'modification_date',
        'role_auth_methods_assoc': 'role_auth_methods_assoc',
        'role_name': 'role_name',
        'rules': 'rules'
    }

    def __init__(self, access_date=None, client_permissions=None, comment=None, creation_date=None, modification_date=None, role_auth_methods_assoc=None, role_name=None, rules=None, local_vars_configuration=None):  # noqa: E501
        """Role - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_date = None
        self._client_permissions = None
        self._comment = None
        self._creation_date = None
        self._modification_date = None
        self._role_auth_methods_assoc = None
        self._role_name = None
        self._rules = None
        self.discriminator = None

        if access_date is not None:
            self.access_date = access_date
        if client_permissions is not None:
            self.client_permissions = client_permissions
        if comment is not None:
            self.comment = comment
        if creation_date is not None:
            self.creation_date = creation_date
        if modification_date is not None:
            self.modification_date = modification_date
        if role_auth_methods_assoc is not None:
            self.role_auth_methods_assoc = role_auth_methods_assoc
        if role_name is not None:
            self.role_name = role_name
        if rules is not None:
            self.rules = rules

    @property
    def access_date(self):
        """Gets the access_date of this Role.  # noqa: E501


        :return: The access_date of this Role.  # noqa: E501
        :rtype: datetime
        """
        return self._access_date

    @access_date.setter
    def access_date(self, access_date):
        """Sets the access_date of this Role.


        :param access_date: The access_date of this Role.  # noqa: E501
        :type: datetime
        """

        self._access_date = access_date

    @property
    def client_permissions(self):
        """Gets the client_permissions of this Role.  # noqa: E501


        :return: The client_permissions of this Role.  # noqa: E501
        :rtype: list[str]
        """
        return self._client_permissions

    @client_permissions.setter
    def client_permissions(self, client_permissions):
        """Sets the client_permissions of this Role.


        :param client_permissions: The client_permissions of this Role.  # noqa: E501
        :type: list[str]
        """

        self._client_permissions = client_permissions

    @property
    def comment(self):
        """Gets the comment of this Role.  # noqa: E501


        :return: The comment of this Role.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Role.


        :param comment: The comment of this Role.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def creation_date(self):
        """Gets the creation_date of this Role.  # noqa: E501


        :return: The creation_date of this Role.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Role.


        :param creation_date: The creation_date of this Role.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def modification_date(self):
        """Gets the modification_date of this Role.  # noqa: E501


        :return: The modification_date of this Role.  # noqa: E501
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """Sets the modification_date of this Role.


        :param modification_date: The modification_date of this Role.  # noqa: E501
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def role_auth_methods_assoc(self):
        """Gets the role_auth_methods_assoc of this Role.  # noqa: E501


        :return: The role_auth_methods_assoc of this Role.  # noqa: E501
        :rtype: list[RoleAuthMethodAssociation]
        """
        return self._role_auth_methods_assoc

    @role_auth_methods_assoc.setter
    def role_auth_methods_assoc(self, role_auth_methods_assoc):
        """Sets the role_auth_methods_assoc of this Role.


        :param role_auth_methods_assoc: The role_auth_methods_assoc of this Role.  # noqa: E501
        :type: list[RoleAuthMethodAssociation]
        """

        self._role_auth_methods_assoc = role_auth_methods_assoc

    @property
    def role_name(self):
        """Gets the role_name of this Role.  # noqa: E501


        :return: The role_name of this Role.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this Role.


        :param role_name: The role_name of this Role.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def rules(self):
        """Gets the rules of this Role.  # noqa: E501


        :return: The rules of this Role.  # noqa: E501
        :rtype: Rules
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this Role.


        :param rules: The rules of this Role.  # noqa: E501
        :type: Rules
        """

        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Role):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Role):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class VaultlessTokenizerInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email_tokenizer_info': 'EmailTokenizerInfo',
        'key_name': 'str',
        'regexp_tokenizer_info': 'RegexpTokenizerInfo',
        'template_type': 'str',
        'tweak': 'str',
        'tweak_type': 'str'
    }

    attribute_map = {
        'email_tokenizer_info': 'email_tokenizer_info',
        'key_name': 'key_name',
        'regexp_tokenizer_info': 'regexp_tokenizer_info',
        'template_type': 'template_type',
        'tweak': 'tweak',
        'tweak_type': 'tweak_type'
    }

    def __init__(self, email_tokenizer_info=None, key_name=None, regexp_tokenizer_info=None, template_type=None, tweak=None, tweak_type=None, local_vars_configuration=None):  # noqa: E501
        """VaultlessTokenizerInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email_tokenizer_info = None
        self._key_name = None
        self._regexp_tokenizer_info = None
        self._template_type = None
        self._tweak = None
        self._tweak_type = None
        self.discriminator = None

        if email_tokenizer_info is not None:
            self.email_tokenizer_info = email_tokenizer_info
        if key_name is not None:
            self.key_name = key_name
        if regexp_tokenizer_info is not None:
            self.regexp_tokenizer_info = regexp_tokenizer_info
        if template_type is not None:
            self.template_type = template_type
        if tweak is not None:
            self.tweak = tweak
        if tweak_type is not None:
            self.tweak_type = tweak_type

    @property
    def email_tokenizer_info(self):
        """Gets the email_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501


        :return: The email_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: EmailTokenizerInfo
        """
        return self._email_tokenizer_info

    @email_tokenizer_info.setter
    def email_tokenizer_info(self, email_tokenizer_info):
        """Sets the email_tokenizer_info of this VaultlessTokenizerInfo.


        :param email_tokenizer_info: The email_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501
        :type: EmailTokenizerInfo
        """

        self._email_tokenizer_info = email_tokenizer_info

    @property
    def key_name(self):
        """Gets the key_name of this VaultlessTokenizerInfo.  # noqa: E501


        :return: The key_name of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this VaultlessTokenizerInfo.


        :param key_name: The key_name of this VaultlessTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._key_name = key_name

    @property
    def regexp_tokenizer_info(self):
        """Gets the regexp_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501


        :return: The regexp_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: RegexpTokenizerInfo
        """
        return self._regexp_tokenizer_info

    @regexp_tokenizer_info.setter
    def regexp_tokenizer_info(self, regexp_tokenizer_info):
        """Sets the regexp_tokenizer_info of this VaultlessTokenizerInfo.


        :param regexp_tokenizer_info: The regexp_tokenizer_info of this VaultlessTokenizerInfo.  # noqa: E501
        :type: RegexpTokenizerInfo
        """

        self._regexp_tokenizer_info = regexp_tokenizer_info

    @property
    def template_type(self):
        """Gets the template_type of this VaultlessTokenizerInfo.  # noqa: E501


        :return: The template_type of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this VaultlessTokenizerInfo.


        :param template_type: The template_type of this VaultlessTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._template_type = template_type

    @property
    def tweak(self):
        """Gets the tweak of this VaultlessTokenizerInfo.  # noqa: E501

        Tweak used in the case of internal tweak type  # noqa: E501

        :return: The tweak of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._tweak

    @tweak.setter
    def tweak(self, tweak):
        """Sets the tweak of this VaultlessTokenizerInfo.

        Tweak used in the case of internal tweak type  # noqa: E501

        :param tweak: The tweak of this VaultlessTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._tweak = tweak

    @property
    def tweak_type(self):
        """Gets the tweak_type of this VaultlessTokenizerInfo.  # noqa: E501


        :return: The tweak_type of this VaultlessTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._tweak_type

    @tweak_type.setter
    def tweak_type(self, tweak_type):
        """Sets the tweak_type of this VaultlessTokenizerInfo.


        :param tweak_type: The tweak_type of this VaultlessTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._tweak_type = tweak_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VaultlessTokenizerInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VaultlessTokenizerInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerAzure(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_obj_id': 'str',
        'azure_client_id': 'str',
        'azure_client_secret': 'str',
        'azure_tenant_id': 'str',
        'delete_protection': 'str',
        'fixed_user_claim_keyname': 'str',
        'fixed_user_only': 'bool',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'producer_encryption_key_name': 'str',
        'secure_access_enable': 'str',
        'secure_access_web': 'bool',
        'secure_access_web_browsing': 'bool',
        'secure_access_web_proxy': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_group_obj_id': 'str',
        'user_portal_access': 'bool',
        'user_principal_name': 'str',
        'user_programmatic_access': 'bool',
        'user_role_template_id': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'app_obj_id': 'app-obj-id',
        'azure_client_id': 'azure-client-id',
        'azure_client_secret': 'azure-client-secret',
        'azure_tenant_id': 'azure-tenant-id',
        'delete_protection': 'delete_protection',
        'fixed_user_claim_keyname': 'fixed-user-claim-keyname',
        'fixed_user_only': 'fixed-user-only',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_web': 'secure-access-web',
        'secure_access_web_browsing': 'secure-access-web-browsing',
        'secure_access_web_proxy': 'secure-access-web-proxy',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_group_obj_id': 'user-group-obj-id',
        'user_portal_access': 'user-portal-access',
        'user_principal_name': 'user-principal-name',
        'user_programmatic_access': 'user-programmatic-access',
        'user_role_template_id': 'user-role-template-id',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, app_obj_id=None, azure_client_id=None, azure_client_secret=None, azure_tenant_id=None, delete_protection=None, fixed_user_claim_keyname='false', fixed_user_only=False, json=None, name=None, new_name=None, producer_encryption_key_name=None, secure_access_enable=None, secure_access_web=None, secure_access_web_browsing=None, secure_access_web_proxy=None, tags=None, target_name=None, token=None, uid_token=None, user_group_obj_id=None, user_portal_access=False, user_principal_name=None, user_programmatic_access=False, user_role_template_id=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerAzure - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_obj_id = None
        self._azure_client_id = None
        self._azure_client_secret = None
        self._azure_tenant_id = None
        self._delete_protection = None
        self._fixed_user_claim_keyname = None
        self._fixed_user_only = None
        self._json = None
        self._name = None
        self._new_name = None
        self._producer_encryption_key_name = None
        self._secure_access_enable = None
        self._secure_access_web = None
        self._secure_access_web_browsing = None
        self._secure_access_web_proxy = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_group_obj_id = None
        self._user_portal_access = None
        self._user_principal_name = None
        self._user_programmatic_access = None
        self._user_role_template_id = None
        self._user_ttl = None
        self.discriminator = None

        if app_obj_id is not None:
            self.app_obj_id = app_obj_id
        if azure_client_id is not None:
            self.azure_client_id = azure_client_id
        if azure_client_secret is not None:
            self.azure_client_secret = azure_client_secret
        if azure_tenant_id is not None:
            self.azure_tenant_id = azure_tenant_id
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if fixed_user_claim_keyname is not None:
            self.fixed_user_claim_keyname = fixed_user_claim_keyname
        if fixed_user_only is not None:
            self.fixed_user_only = fixed_user_only
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if secure_access_web_browsing is not None:
            self.secure_access_web_browsing = secure_access_web_browsing
        if secure_access_web_proxy is not None:
            self.secure_access_web_proxy = secure_access_web_proxy
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_group_obj_id is not None:
            self.user_group_obj_id = user_group_obj_id
        if user_portal_access is not None:
            self.user_portal_access = user_portal_access
        if user_principal_name is not None:
            self.user_principal_name = user_principal_name
        if user_programmatic_access is not None:
            self.user_programmatic_access = user_programmatic_access
        if user_role_template_id is not None:
            self.user_role_template_id = user_role_template_id
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def app_obj_id(self):
        """Gets the app_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure App Object Id  # noqa: E501

        :return: The app_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._app_obj_id

    @app_obj_id.setter
    def app_obj_id(self, app_obj_id):
        """Sets the app_obj_id of this GatewayUpdateProducerAzure.

        Azure App Object Id  # noqa: E501

        :param app_obj_id: The app_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._app_obj_id = app_obj_id

    @property
    def azure_client_id(self):
        """Gets the azure_client_id of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure Client ID  # noqa: E501

        :return: The azure_client_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._azure_client_id

    @azure_client_id.setter
    def azure_client_id(self, azure_client_id):
        """Sets the azure_client_id of this GatewayUpdateProducerAzure.

        Azure Client ID  # noqa: E501

        :param azure_client_id: The azure_client_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._azure_client_id = azure_client_id

    @property
    def azure_client_secret(self):
        """Gets the azure_client_secret of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure Client Secret  # noqa: E501

        :return: The azure_client_secret of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._azure_client_secret

    @azure_client_secret.setter
    def azure_client_secret(self, azure_client_secret):
        """Sets the azure_client_secret of this GatewayUpdateProducerAzure.

        Azure Client Secret  # noqa: E501

        :param azure_client_secret: The azure_client_secret of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._azure_client_secret = azure_client_secret

    @property
    def azure_tenant_id(self):
        """Gets the azure_tenant_id of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure Tenant ID  # noqa: E501

        :return: The azure_tenant_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._azure_tenant_id

    @azure_tenant_id.setter
    def azure_tenant_id(self, azure_tenant_id):
        """Sets the azure_tenant_id of this GatewayUpdateProducerAzure.

        Azure Tenant ID  # noqa: E501

        :param azure_tenant_id: The azure_tenant_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._azure_tenant_id = azure_tenant_id

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerAzure.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerAzure.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def fixed_user_claim_keyname(self):
        """Gets the fixed_user_claim_keyname of this GatewayUpdateProducerAzure.  # noqa: E501

        FixedUserClaimKeyname  # noqa: E501

        :return: The fixed_user_claim_keyname of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._fixed_user_claim_keyname

    @fixed_user_claim_keyname.setter
    def fixed_user_claim_keyname(self, fixed_user_claim_keyname):
        """Sets the fixed_user_claim_keyname of this GatewayUpdateProducerAzure.

        FixedUserClaimKeyname  # noqa: E501

        :param fixed_user_claim_keyname: The fixed_user_claim_keyname of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._fixed_user_claim_keyname = fixed_user_claim_keyname

    @property
    def fixed_user_only(self):
        """Gets the fixed_user_only of this GatewayUpdateProducerAzure.  # noqa: E501

        Fixed user  # noqa: E501

        :return: The fixed_user_only of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_user_only

    @fixed_user_only.setter
    def fixed_user_only(self, fixed_user_only):
        """Sets the fixed_user_only of this GatewayUpdateProducerAzure.

        Fixed user  # noqa: E501

        :param fixed_user_only: The fixed_user_only of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._fixed_user_only = fixed_user_only

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerAzure.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerAzure.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerAzure.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerAzure.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerAzure.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerAzure.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerAzure.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerAzure.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerAzure.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerAzure.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayUpdateProducerAzure.  # noqa: E501


        :return: The secure_access_web of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayUpdateProducerAzure.


        :param secure_access_web: The secure_access_web of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def secure_access_web_browsing(self):
        """Gets the secure_access_web_browsing of this GatewayUpdateProducerAzure.  # noqa: E501


        :return: The secure_access_web_browsing of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_browsing

    @secure_access_web_browsing.setter
    def secure_access_web_browsing(self, secure_access_web_browsing):
        """Sets the secure_access_web_browsing of this GatewayUpdateProducerAzure.


        :param secure_access_web_browsing: The secure_access_web_browsing of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_browsing = secure_access_web_browsing

    @property
    def secure_access_web_proxy(self):
        """Gets the secure_access_web_proxy of this GatewayUpdateProducerAzure.  # noqa: E501


        :return: The secure_access_web_proxy of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_proxy

    @secure_access_web_proxy.setter
    def secure_access_web_proxy(self, secure_access_web_proxy):
        """Sets the secure_access_web_proxy of this GatewayUpdateProducerAzure.


        :param secure_access_web_proxy: The secure_access_web_proxy of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_proxy = secure_access_web_proxy

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerAzure.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerAzure.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerAzure.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerAzure.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerAzure.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerAzure.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerAzure.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerAzure.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_group_obj_id(self):
        """Gets the user_group_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501

        User Group Object Id  # noqa: E501

        :return: The user_group_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._user_group_obj_id

    @user_group_obj_id.setter
    def user_group_obj_id(self, user_group_obj_id):
        """Sets the user_group_obj_id of this GatewayUpdateProducerAzure.

        User Group Object Id  # noqa: E501

        :param user_group_obj_id: The user_group_obj_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._user_group_obj_id = user_group_obj_id

    @property
    def user_portal_access(self):
        """Gets the user_portal_access of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure User portal access  # noqa: E501

        :return: The user_portal_access of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._user_portal_access

    @user_portal_access.setter
    def user_portal_access(self, user_portal_access):
        """Sets the user_portal_access of this GatewayUpdateProducerAzure.

        Azure User portal access  # noqa: E501

        :param user_portal_access: The user_portal_access of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._user_portal_access = user_portal_access

    @property
    def user_principal_name(self):
        """Gets the user_principal_name of this GatewayUpdateProducerAzure.  # noqa: E501

        User Principal Name  # noqa: E501

        :return: The user_principal_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._user_principal_name

    @user_principal_name.setter
    def user_principal_name(self, user_principal_name):
        """Sets the user_principal_name of this GatewayUpdateProducerAzure.

        User Principal Name  # noqa: E501

        :param user_principal_name: The user_principal_name of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._user_principal_name = user_principal_name

    @property
    def user_programmatic_access(self):
        """Gets the user_programmatic_access of this GatewayUpdateProducerAzure.  # noqa: E501

        Azure User programmatic access  # noqa: E501

        :return: The user_programmatic_access of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: bool
        """
        return self._user_programmatic_access

    @user_programmatic_access.setter
    def user_programmatic_access(self, user_programmatic_access):
        """Sets the user_programmatic_access of this GatewayUpdateProducerAzure.

        Azure User programmatic access  # noqa: E501

        :param user_programmatic_access: The user_programmatic_access of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: bool
        """

        self._user_programmatic_access = user_programmatic_access

    @property
    def user_role_template_id(self):
        """Gets the user_role_template_id of this GatewayUpdateProducerAzure.  # noqa: E501

        User Role Template Id  # noqa: E501

        :return: The user_role_template_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._user_role_template_id

    @user_role_template_id.setter
    def user_role_template_id(self, user_role_template_id):
        """Sets the user_role_template_id of this GatewayUpdateProducerAzure.

        User Role Template Id  # noqa: E501

        :param user_role_template_id: The user_role_template_id of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._user_role_template_id = user_role_template_id

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerAzure.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerAzure.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerAzure.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerAzure.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerAzure):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerAzure):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerPostgreSQL(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'creation_statements': 'str',
        'delete_protection': 'str',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'postgresql_db_name': 'str',
        'postgresql_host': 'str',
        'postgresql_password': 'str',
        'postgresql_port': 'str',
        'postgresql_username': 'str',
        'producer_encryption_key': 'str',
        'revocation_statement': 'str',
        'secure_access_bastion_issuer': 'str',
        'secure_access_db_schema': 'str',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_web': 'bool',
        'ssl': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'creation_statements': 'creation-statements',
        'delete_protection': 'delete_protection',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'postgresql_db_name': 'postgresql-db-name',
        'postgresql_host': 'postgresql-host',
        'postgresql_password': 'postgresql-password',
        'postgresql_port': 'postgresql-port',
        'postgresql_username': 'postgresql-username',
        'producer_encryption_key': 'producer-encryption-key',
        'revocation_statement': 'revocation-statement',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_db_schema': 'secure-access-db-schema',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_web': 'secure-access-web',
        'ssl': 'ssl',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, creation_statements=None, delete_protection=None, json=None, name=None, new_name=None, postgresql_db_name=None, postgresql_host='127.0.0.1', postgresql_password=None, postgresql_port='5432', postgresql_username=None, producer_encryption_key=None, revocation_statement=None, secure_access_bastion_issuer=None, secure_access_db_schema=None, secure_access_enable=None, secure_access_host=None, secure_access_web=None, ssl=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerPostgreSQL - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._creation_statements = None
        self._delete_protection = None
        self._json = None
        self._name = None
        self._new_name = None
        self._postgresql_db_name = None
        self._postgresql_host = None
        self._postgresql_password = None
        self._postgresql_port = None
        self._postgresql_username = None
        self._producer_encryption_key = None
        self._revocation_statement = None
        self._secure_access_bastion_issuer = None
        self._secure_access_db_schema = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_web = None
        self._ssl = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if creation_statements is not None:
            self.creation_statements = creation_statements
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if postgresql_db_name is not None:
            self.postgresql_db_name = postgresql_db_name
        if postgresql_host is not None:
            self.postgresql_host = postgresql_host
        if postgresql_password is not None:
            self.postgresql_password = postgresql_password
        if postgresql_port is not None:
            self.postgresql_port = postgresql_port
        if postgresql_username is not None:
            self.postgresql_username = postgresql_username
        if producer_encryption_key is not None:
            self.producer_encryption_key = producer_encryption_key
        if revocation_statement is not None:
            self.revocation_statement = revocation_statement
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_db_schema is not None:
            self.secure_access_db_schema = secure_access_db_schema
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if ssl is not None:
            self.ssl = ssl
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def creation_statements(self):
        """Gets the creation_statements of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Creation statements  # noqa: E501

        :return: The creation_statements of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._creation_statements

    @creation_statements.setter
    def creation_statements(self, creation_statements):
        """Sets the creation_statements of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Creation statements  # noqa: E501

        :param creation_statements: The creation_statements of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._creation_statements = creation_statements

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerPostgreSQL.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerPostgreSQL.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerPostgreSQL.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerPostgreSQL.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def postgresql_db_name(self):
        """Gets the postgresql_db_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL DB Name  # noqa: E501

        :return: The postgresql_db_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._postgresql_db_name

    @postgresql_db_name.setter
    def postgresql_db_name(self, postgresql_db_name):
        """Sets the postgresql_db_name of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL DB Name  # noqa: E501

        :param postgresql_db_name: The postgresql_db_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._postgresql_db_name = postgresql_db_name

    @property
    def postgresql_host(self):
        """Gets the postgresql_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Host  # noqa: E501

        :return: The postgresql_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._postgresql_host

    @postgresql_host.setter
    def postgresql_host(self, postgresql_host):
        """Sets the postgresql_host of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Host  # noqa: E501

        :param postgresql_host: The postgresql_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._postgresql_host = postgresql_host

    @property
    def postgresql_password(self):
        """Gets the postgresql_password of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Password  # noqa: E501

        :return: The postgresql_password of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._postgresql_password

    @postgresql_password.setter
    def postgresql_password(self, postgresql_password):
        """Sets the postgresql_password of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Password  # noqa: E501

        :param postgresql_password: The postgresql_password of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._postgresql_password = postgresql_password

    @property
    def postgresql_port(self):
        """Gets the postgresql_port of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Port  # noqa: E501

        :return: The postgresql_port of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._postgresql_port

    @postgresql_port.setter
    def postgresql_port(self, postgresql_port):
        """Sets the postgresql_port of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Port  # noqa: E501

        :param postgresql_port: The postgresql_port of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._postgresql_port = postgresql_port

    @property
    def postgresql_username(self):
        """Gets the postgresql_username of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Username  # noqa: E501

        :return: The postgresql_username of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._postgresql_username

    @postgresql_username.setter
    def postgresql_username(self, postgresql_username):
        """Sets the postgresql_username of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Username  # noqa: E501

        :param postgresql_username: The postgresql_username of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._postgresql_username = postgresql_username

    @property
    def producer_encryption_key(self):
        """Gets the producer_encryption_key of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key

    @producer_encryption_key.setter
    def producer_encryption_key(self, producer_encryption_key):
        """Sets the producer_encryption_key of this GatewayUpdateProducerPostgreSQL.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key: The producer_encryption_key of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key = producer_encryption_key

    @property
    def revocation_statement(self):
        """Gets the revocation_statement of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        PostgreSQL Revocation statements  # noqa: E501

        :return: The revocation_statement of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._revocation_statement

    @revocation_statement.setter
    def revocation_statement(self, revocation_statement):
        """Sets the revocation_statement of this GatewayUpdateProducerPostgreSQL.

        PostgreSQL Revocation statements  # noqa: E501

        :param revocation_statement: The revocation_statement of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._revocation_statement = revocation_statement

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this GatewayUpdateProducerPostgreSQL.  # noqa: E501


        :return: The secure_access_bastion_issuer of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this GatewayUpdateProducerPostgreSQL.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_db_schema(self):
        """Gets the secure_access_db_schema of this GatewayUpdateProducerPostgreSQL.  # noqa: E501


        :return: The secure_access_db_schema of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_db_schema

    @secure_access_db_schema.setter
    def secure_access_db_schema(self, secure_access_db_schema):
        """Sets the secure_access_db_schema of this GatewayUpdateProducerPostgreSQL.


        :param secure_access_db_schema: The secure_access_db_schema of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._secure_access_db_schema = secure_access_db_schema

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerPostgreSQL.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerPostgreSQL.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501


        :return: The secure_access_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this GatewayUpdateProducerPostgreSQL.


        :param secure_access_host: The secure_access_host of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayUpdateProducerPostgreSQL.  # noqa: E501


        :return: The secure_access_web of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayUpdateProducerPostgreSQL.


        :param secure_access_web: The secure_access_web of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def ssl(self):
        """Gets the ssl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        SSL connection mode  # noqa: E501

        :return: The ssl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: bool
        """
        return self._ssl

    @ssl.setter
    def ssl(self, ssl):
        """Sets the ssl of this GatewayUpdateProducerPostgreSQL.

        SSL connection mode  # noqa: E501

        :param ssl: The ssl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: bool
        """

        self._ssl = ssl

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerPostgreSQL.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerPostgreSQL.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerPostgreSQL.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerPostgreSQL.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerPostgreSQL.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerPostgreSQL.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerPostgreSQL):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerPostgreSQL):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerOracleDb(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'db_server_certificates': 'str',
        'db_server_name': 'str',
        'delete_protection': 'str',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'oracle_host': 'str',
        'oracle_password': 'str',
        'oracle_port': 'str',
        'oracle_screation_statements': 'str',
        'oracle_service_name': 'str',
        'oracle_username': 'str',
        'producer_encryption_key_name': 'str',
        'secure_access_bastion_issuer': 'str',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_web': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'db_server_certificates': 'db-server-certificates',
        'db_server_name': 'db-server-name',
        'delete_protection': 'delete_protection',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'oracle_host': 'oracle-host',
        'oracle_password': 'oracle-password',
        'oracle_port': 'oracle-port',
        'oracle_screation_statements': 'oracle-screation-statements',
        'oracle_service_name': 'oracle-service-name',
        'oracle_username': 'oracle-username',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_web': 'secure-access-web',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, db_server_certificates=None, db_server_name=None, delete_protection=None, json=None, name=None, new_name=None, oracle_host='127.0.0.1', oracle_password=None, oracle_port='1521', oracle_screation_statements=None, oracle_service_name=None, oracle_username=None, producer_encryption_key_name=None, secure_access_bastion_issuer=None, secure_access_enable=None, secure_access_host=None, secure_access_web=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerOracleDb - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._db_server_certificates = None
        self._db_server_name = None
        self._delete_protection = None
        self._json = None
        self._name = None
        self._new_name = None
        self._oracle_host = None
        self._oracle_password = None
        self._oracle_port = None
        self._oracle_screation_statements = None
        self._oracle_service_name = None
        self._oracle_username = None
        self._producer_encryption_key_name = None
        self._secure_access_bastion_issuer = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_web = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if db_server_certificates is not None:
            self.db_server_certificates = db_server_certificates
        if db_server_name is not None:
            self.db_server_name = db_server_name
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if oracle_host is not None:
            self.oracle_host = oracle_host
        if oracle_password is not None:
            self.oracle_password = oracle_password
        if oracle_port is not None:
            self.oracle_port = oracle_port
        if oracle_screation_statements is not None:
            self.oracle_screation_statements = oracle_screation_statements
        if oracle_service_name is not None:
            self.oracle_service_name = oracle_service_name
        if oracle_username is not None:
            self.oracle_username = oracle_username
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def db_server_certificates(self):
        """Gets the db_server_certificates of this GatewayUpdateProducerOracleDb.  # noqa: E501

        (Optional) DB server certificates  # noqa: E501

        :return: The db_server_certificates of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._db_server_certificates

    @db_server_certificates.setter
    def db_server_certificates(self, db_server_certificates):
        """Sets the db_server_certificates of this GatewayUpdateProducerOracleDb.

        (Optional) DB server certificates  # noqa: E501

        :param db_server_certificates: The db_server_certificates of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._db_server_certificates = db_server_certificates

    @property
    def db_server_name(self):
        """Gets the db_server_name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        (Optional) Server name for certificate verification  # noqa: E501

        :return: The db_server_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._db_server_name

    @db_server_name.setter
    def db_server_name(self, db_server_name):
        """Sets the db_server_name of this GatewayUpdateProducerOracleDb.

        (Optional) Server name for certificate verification  # noqa: E501

        :param db_server_name: The db_server_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._db_server_name = db_server_name

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerOracleDb.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerOracleDb.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerOracleDb.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerOracleDb.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def oracle_host(self):
        """Gets the oracle_host of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle Host  # noqa: E501

        :return: The oracle_host of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_host

    @oracle_host.setter
    def oracle_host(self, oracle_host):
        """Sets the oracle_host of this GatewayUpdateProducerOracleDb.

        Oracle Host  # noqa: E501

        :param oracle_host: The oracle_host of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_host = oracle_host

    @property
    def oracle_password(self):
        """Gets the oracle_password of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle Password  # noqa: E501

        :return: The oracle_password of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_password

    @oracle_password.setter
    def oracle_password(self, oracle_password):
        """Sets the oracle_password of this GatewayUpdateProducerOracleDb.

        Oracle Password  # noqa: E501

        :param oracle_password: The oracle_password of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_password = oracle_password

    @property
    def oracle_port(self):
        """Gets the oracle_port of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle Port  # noqa: E501

        :return: The oracle_port of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_port

    @oracle_port.setter
    def oracle_port(self, oracle_port):
        """Sets the oracle_port of this GatewayUpdateProducerOracleDb.

        Oracle Port  # noqa: E501

        :param oracle_port: The oracle_port of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_port = oracle_port

    @property
    def oracle_screation_statements(self):
        """Gets the oracle_screation_statements of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle Creation statements  # noqa: E501

        :return: The oracle_screation_statements of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_screation_statements

    @oracle_screation_statements.setter
    def oracle_screation_statements(self, oracle_screation_statements):
        """Sets the oracle_screation_statements of this GatewayUpdateProducerOracleDb.

        Oracle Creation statements  # noqa: E501

        :param oracle_screation_statements: The oracle_screation_statements of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_screation_statements = oracle_screation_statements

    @property
    def oracle_service_name(self):
        """Gets the oracle_service_name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle DB Name  # noqa: E501

        :return: The oracle_service_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_service_name

    @oracle_service_name.setter
    def oracle_service_name(self, oracle_service_name):
        """Sets the oracle_service_name of this GatewayUpdateProducerOracleDb.

        Oracle DB Name  # noqa: E501

        :param oracle_service_name: The oracle_service_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_service_name = oracle_service_name

    @property
    def oracle_username(self):
        """Gets the oracle_username of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Oracle Username  # noqa: E501

        :return: The oracle_username of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._oracle_username

    @oracle_username.setter
    def oracle_username(self, oracle_username):
        """Sets the oracle_username of this GatewayUpdateProducerOracleDb.

        Oracle Username  # noqa: E501

        :param oracle_username: The oracle_username of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._oracle_username = oracle_username

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerOracleDb.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this GatewayUpdateProducerOracleDb.  # noqa: E501


        :return: The secure_access_bastion_issuer of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this GatewayUpdateProducerOracleDb.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerOracleDb.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerOracleDb.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this GatewayUpdateProducerOracleDb.  # noqa: E501


        :return: The secure_access_host of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this GatewayUpdateProducerOracleDb.


        :param secure_access_host: The secure_access_host of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayUpdateProducerOracleDb.  # noqa: E501


        :return: The secure_access_web of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayUpdateProducerOracleDb.


        :param secure_access_web: The secure_access_web of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerOracleDb.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerOracleDb.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerOracleDb.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerOracleDb.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerOracleDb.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerOracleDb.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerOracleDb.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerOracleDb.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerOracleDb.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerOracleDb.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerOracleDb):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerOracleDb):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.classic_key_details_info import ClassicKeyDetailsInfo  # noqa: E501
from akeyless.rest import ApiException

class TestClassicKeyDetailsInfo(unittest.TestCase):
    """ClassicKeyDetailsInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClassicKeyDetailsInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.classic_key_details_info.ClassicKeyDetailsInfo()  # noqa: E501
        if include_optional :
            return ClassicKeyDetailsInfo(
                classic_key_id = '0', 
                is_provided_by_user = True, 
                is_unexportable = True, 
                key_state = '0', 
                key_type = '0', 
                last_error = '0', 
                target_alias_helper = '0', 
                target_types = [
                    '0'
                    ], 
                targets = [
                    akeyless.models.classic_key_target_info.ClassicKeyTargetInfo(
                        external_kms_id = akeyless.models.external_kms_key_id.ExternalKMSKeyId(
                            key_id = '0', 
                            key_reference = '0', ), 
                        key_purpose = [
                            '0'
                            ], 
                        key_status = akeyless.models.classic_key_status_info.ClassicKeyStatusInfo(
                            error_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            last_error = '0', 
                            last_status = '0', 
                            version = 56, ), 
                        target_assoc_id = '0', 
                        target_type = '0', )
                    ]
            )
        else :
            return ClassicKeyDetailsInfo(
        )

    def testClassicKeyDetailsInfo(self):
        """Test ClassicKeyDetailsInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GetCloudIdentity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'azure_ad_object_id': 'str',
        'debug': 'bool',
        'gcp_audience': 'str',
        'json': 'bool',
        'url_safe': 'bool'
    }

    attribute_map = {
        'azure_ad_object_id': 'azure_ad_object_id',
        'debug': 'debug',
        'gcp_audience': 'gcp-audience',
        'json': 'json',
        'url_safe': 'url_safe'
    }

    def __init__(self, azure_ad_object_id=None, debug=None, gcp_audience=None, json=None, url_safe=None, local_vars_configuration=None):  # noqa: E501
        """GetCloudIdentity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._azure_ad_object_id = None
        self._debug = None
        self._gcp_audience = None
        self._json = None
        self._url_safe = None
        self.discriminator = None

        if azure_ad_object_id is not None:
            self.azure_ad_object_id = azure_ad_object_id
        if debug is not None:
            self.debug = debug
        if gcp_audience is not None:
            self.gcp_audience = gcp_audience
        if json is not None:
            self.json = json
        if url_safe is not None:
            self.url_safe = url_safe

    @property
    def azure_ad_object_id(self):
        """Gets the azure_ad_object_id of this GetCloudIdentity.  # noqa: E501

        Azure Active Directory ObjectId (relevant only for access-type=azure_ad)  # noqa: E501

        :return: The azure_ad_object_id of this GetCloudIdentity.  # noqa: E501
        :rtype: str
        """
        return self._azure_ad_object_id

    @azure_ad_object_id.setter
    def azure_ad_object_id(self, azure_ad_object_id):
        """Sets the azure_ad_object_id of this GetCloudIdentity.

        Azure Active Directory ObjectId (relevant only for access-type=azure_ad)  # noqa: E501

        :param azure_ad_object_id: The azure_ad_object_id of this GetCloudIdentity.  # noqa: E501
        :type: str
        """

        self._azure_ad_object_id = azure_ad_object_id

    @property
    def debug(self):
        """Gets the debug of this GetCloudIdentity.  # noqa: E501


        :return: The debug of this GetCloudIdentity.  # noqa: E501
        :rtype: bool
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        """Sets the debug of this GetCloudIdentity.


        :param debug: The debug of this GetCloudIdentity.  # noqa: E501
        :type: bool
        """

        self._debug = debug

    @property
    def gcp_audience(self):
        """Gets the gcp_audience of this GetCloudIdentity.  # noqa: E501

        GCP JWT audience  # noqa: E501

        :return: The gcp_audience of this GetCloudIdentity.  # noqa: E501
        :rtype: str
        """
        return self._gcp_audience

    @gcp_audience.setter
    def gcp_audience(self, gcp_audience):
        """Sets the gcp_audience of this GetCloudIdentity.

        GCP JWT audience  # noqa: E501

        :param gcp_audience: The gcp_audience of this GetCloudIdentity.  # noqa: E501
        :type: str
        """

        self._gcp_audience = gcp_audience

    @property
    def json(self):
        """Gets the json of this GetCloudIdentity.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GetCloudIdentity.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GetCloudIdentity.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GetCloudIdentity.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def url_safe(self):
        """Gets the url_safe of this GetCloudIdentity.  # noqa: E501

        Escapes the token so it can be safely placed inside a URL query  # noqa: E501

        :return: The url_safe of this GetCloudIdentity.  # noqa: E501
        :rtype: bool
        """
        return self._url_safe

    @url_safe.setter
    def url_safe(self, url_safe):
        """Sets the url_safe of this GetCloudIdentity.

        Escapes the token so it can be safely placed inside a URL query  # noqa: E501

        :param url_safe: The url_safe of this GetCloudIdentity.  # noqa: E501
        :type: bool
        """

        self._url_safe = url_safe

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCloudIdentity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetCloudIdentity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GCPAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'audience': 'str',
        'bound_labels': 'dict(str, str)',
        'bound_projects': 'list[str]',
        'bound_regions': 'list[str]',
        'bound_service_accounts': 'list[str]',
        'bound_zones': 'list[str]',
        'service_account': 'str',
        'type': 'str'
    }

    attribute_map = {
        'audience': 'audience',
        'bound_labels': 'bound_labels',
        'bound_projects': 'bound_projects',
        'bound_regions': 'bound_regions',
        'bound_service_accounts': 'bound_service_accounts',
        'bound_zones': 'bound_zones',
        'service_account': 'service_account',
        'type': 'type'
    }

    def __init__(self, audience='akeyless.io', bound_labels=None, bound_projects=None, bound_regions=None, bound_service_accounts=None, bound_zones=None, service_account=None, type=None, local_vars_configuration=None):  # noqa: E501
        """GCPAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._audience = None
        self._bound_labels = None
        self._bound_projects = None
        self._bound_regions = None
        self._bound_service_accounts = None
        self._bound_zones = None
        self._service_account = None
        self._type = None
        self.discriminator = None

        if audience is not None:
            self.audience = audience
        if bound_labels is not None:
            self.bound_labels = bound_labels
        if bound_projects is not None:
            self.bound_projects = bound_projects
        if bound_regions is not None:
            self.bound_regions = bound_regions
        if bound_service_accounts is not None:
            self.bound_service_accounts = bound_service_accounts
        if bound_zones is not None:
            self.bound_zones = bound_zones
        if service_account is not None:
            self.service_account = service_account
        if type is not None:
            self.type = type

    @property
    def audience(self):
        """Gets the audience of this GCPAccessRules.  # noqa: E501

        The audience in the JWT  # noqa: E501

        :return: The audience of this GCPAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this GCPAccessRules.

        The audience in the JWT  # noqa: E501

        :param audience: The audience of this GCPAccessRules.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def bound_labels(self):
        """Gets the bound_labels of this GCPAccessRules.  # noqa: E501

        A map of GCP labels formatted as \"key:value\" strings that must be set on authorized GCE instances. TODO: Because GCP labels are not currently ACL'd ....  # noqa: E501

        :return: The bound_labels of this GCPAccessRules.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._bound_labels

    @bound_labels.setter
    def bound_labels(self, bound_labels):
        """Sets the bound_labels of this GCPAccessRules.

        A map of GCP labels formatted as \"key:value\" strings that must be set on authorized GCE instances. TODO: Because GCP labels are not currently ACL'd ....  # noqa: E501

        :param bound_labels: The bound_labels of this GCPAccessRules.  # noqa: E501
        :type: dict(str, str)
        """

        self._bound_labels = bound_labels

    @property
    def bound_projects(self):
        """Gets the bound_projects of this GCPAccessRules.  # noqa: E501

        Human and Machine authentication section Array of GCP project IDs. Only entities belonging to any of the provided projects can authenticate.  # noqa: E501

        :return: The bound_projects of this GCPAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_projects

    @bound_projects.setter
    def bound_projects(self, bound_projects):
        """Sets the bound_projects of this GCPAccessRules.

        Human and Machine authentication section Array of GCP project IDs. Only entities belonging to any of the provided projects can authenticate.  # noqa: E501

        :param bound_projects: The bound_projects of this GCPAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_projects = bound_projects

    @property
    def bound_regions(self):
        """Gets the bound_regions of this GCPAccessRules.  # noqa: E501

        List of regions that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a regional group and the group must belong to this region. If bound_zones are provided, this attribute is ignored.  # noqa: E501

        :return: The bound_regions of this GCPAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_regions

    @bound_regions.setter
    def bound_regions(self, bound_regions):
        """Sets the bound_regions of this GCPAccessRules.

        List of regions that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a regional group and the group must belong to this region. If bound_zones are provided, this attribute is ignored.  # noqa: E501

        :param bound_regions: The bound_regions of this GCPAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_regions = bound_regions

    @property
    def bound_service_accounts(self):
        """Gets the bound_service_accounts of this GCPAccessRules.  # noqa: E501

        List of service accounts the service account must be part of in order to be authenticated  # noqa: E501

        :return: The bound_service_accounts of this GCPAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_service_accounts

    @bound_service_accounts.setter
    def bound_service_accounts(self, bound_service_accounts):
        """Sets the bound_service_accounts of this GCPAccessRules.

        List of service accounts the service account must be part of in order to be authenticated  # noqa: E501

        :param bound_service_accounts: The bound_service_accounts of this GCPAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_service_accounts = bound_service_accounts

    @property
    def bound_zones(self):
        """Gets the bound_zones of this GCPAccessRules.  # noqa: E501

        === Machine authentication section === List of zones that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a zonal group and the group must belong to this zone.  # noqa: E501

        :return: The bound_zones of this GCPAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_zones

    @bound_zones.setter
    def bound_zones(self, bound_zones):
        """Sets the bound_zones of this GCPAccessRules.

        === Machine authentication section === List of zones that a GCE instance must belong to in order to be authenticated. TODO: If bound_instance_groups is provided, it is assumed to be a zonal group and the group must belong to this zone.  # noqa: E501

        :param bound_zones: The bound_zones of this GCPAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_zones = bound_zones

    @property
    def service_account(self):
        """Gets the service_account of this GCPAccessRules.  # noqa: E501

        ServiceAccount holds the credentials file contents to be used by Akeyless to validate IAM (Human) and GCE (Machine) logins against GCP base64 encoded string  # noqa: E501

        :return: The service_account of this GCPAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._service_account

    @service_account.setter
    def service_account(self, service_account):
        """Sets the service_account of this GCPAccessRules.

        ServiceAccount holds the credentials file contents to be used by Akeyless to validate IAM (Human) and GCE (Machine) logins against GCP base64 encoded string  # noqa: E501

        :param service_account: The service_account of this GCPAccessRules.  # noqa: E501
        :type: str
        """

        self._service_account = service_account

    @property
    def type(self):
        """Gets the type of this GCPAccessRules.  # noqa: E501


        :return: The type of this GCPAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GCPAccessRules.


        :param type: The type of this GCPAccessRules.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GCPAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GCPAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.auth_method_access_info import AuthMethodAccessInfo  # noqa: E501
from akeyless.rest import ApiException

class TestAuthMethodAccessInfo(unittest.TestCase):
    """AuthMethodAccessInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuthMethodAccessInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.auth_method_access_info.AuthMethodAccessInfo()  # noqa: E501
        if include_optional :
            return AuthMethodAccessInfo(
                access_expires = 56, 
                api_key_access_rules = akeyless.models.api_key_access_rules_is_a_set_of_rules_for_api_key_access_type/.APIKeyAccessRules is a set of rules for API Key access type.(
                    alg = '0', 
                    key = '0', ), 
                aws_iam_access_rules = akeyless.models.awsiam_access_rules_contains_access_rules_specific_to_aws_iam/.AWSIAMAccessRules contains access rules specific to AWS IAM.(
                    account_id = [
                        '0'
                        ], 
                    arn = [
                        '0'
                        ], 
                    resource_id = [
                        '0'
                        ], 
                    role_id = [
                        '0'
                        ], 
                    role_name = [
                        '0'
                        ], 
                    sts_endpoint = '0', 
                    user_id = [
                        '0'
                        ], 
                    user_name = [
                        '0'
                        ], ), 
                azure_ad_access_rules = akeyless.models.azure_ad_access_rules.AzureADAccessRules(
                    ad_endpoint = '0', 
                    bound_group_ids = [
                        '0'
                        ], 
                    bound_resource_groups = [
                        '0'
                        ], 
                    bound_resource_ids = [
                        '0'
                        ], 
                    bound_resource_names = [
                        '0'
                        ], 
                    bound_resource_providers = [
                        '0'
                        ], 
                    bound_resource_types = [
                        '0'
                        ], 
                    bound_service_principal_ids = [
                        '0'
                        ], 
                    bound_subscription_ids = [
                        '0'
                        ], 
                    bound_tenant_id = '0', 
                    issuer = '0', 
                    jwks_uri = '0', ), 
                cidr_whitelist = '0', 
                email_pass_access_rules = akeyless.models.email_pass_access_rules_is_a_set_of_rules_for_email_password_access_type/.EmailPassAccessRules is a set of rules for email password access type.(
                    alg = '0', 
                    email = '0', 
                    hash_pass = '0', ), 
                huawei_access_rules = akeyless.models.huawei_access_rules_defines_access_rules_specific_to_huawei_authentication/.HuaweiAccessRules defines access rules specific to Huawei authentication.(
                    auth_endpoint = '0', 
                    domain_id = [
                        '0'
                        ], 
                    domain_name = [
                        '0'
                        ], 
                    tenant_id = [
                        '0'
                        ], 
                    tenant_name = [
                        '0'
                        ], 
                    user_id = [
                        '0'
                        ], 
                    user_name = [
                        '0'
                        ], ), 
                ldap_access_rules = akeyless.models.ldap_access_rules_includes_access_rules_specific_to_ldap_authentication/.LDAPAccessRules includes access rules specific to LDAP authentication.(
                    alg = '0', 
                    key = '0', ), 
                oauth2_access_rules = akeyless.models.o_auth2_access_rules.OAuth2AccessRules(
                    audience = '0', 
                    bound_claims = [
                        akeyless.models.o_auth2_custom_claim.OAuth2CustomClaim(
                            name = '0', 
                            values = [
                                '0'
                                ], )
                        ], 
                    bound_clients_id = [
                        '0'
                        ], 
                    issuer = '0', 
                    jwks_uri = '0', ), 
                rules_type = '0', 
                saml_access_rules = akeyless.models.saml_access_rules_defines_access_rules_specific_to_saml_authentication_method/.SAMLAccessRules defines access rules specific to SAML authentication method.(
                    bound_attributes = [
                        akeyless.models.saml_attribute_defines_an_attribute_of_saml_authentication/.SAMLAttribute defines an attribute of SAML authentication.(
                            name = '0', 
                            values = [
                                '0'
                                ], )
                        ], 
                    idp_metadata_url = '0', 
                    idp_metadata_xml = '0', ), 
                universal_identity_access_rules = akeyless.models.universal_identity_access_rules_contains_access_rules_specific_to_universal_identity/.UniversalIdentityAccessRules contains access rules specific to Universal Identity.(
                    deny_inheritance = True, 
                    deny_rotate = True, 
                    ttl = 56, )
            )
        else :
            return AuthMethodAccessInfo(
        )

    def testAuthMethodAccessInfo(self):
        """Test AuthMethodAccessInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_update_k8_s_auth_config_output import GatewayUpdateK8SAuthConfigOutput  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayUpdateK8SAuthConfigOutput(unittest.TestCase):
    """GatewayUpdateK8SAuthConfigOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayUpdateK8SAuthConfigOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_update_k8_s_auth_config_output.GatewayUpdateK8SAuthConfigOutput()  # noqa: E501
        if include_optional :
            return GatewayUpdateK8SAuthConfigOutput(
                cluster_id = '0', 
                parts_change = akeyless.models.config_change.ConfigChange(
                    config_hash = akeyless.models.config_hash.ConfigHash(
                        admins = '0', 
                        cache = '0', 
                        customer_fragements = '0', 
                        general = '0', 
                        k8s_auths = '0', 
                        kmip = '0', 
                        ldap = '0', 
                        leadership = '0', 
                        log_forwarding = '0', 
                        m_queue = '0', 
                        migrations = '0', 
                        producers = akeyless.models.producers.producers(), 
                        rotators = akeyless.models.rotators.rotators(), 
                        saml = '0', 
                        universal_identity = '0', ), 
                    last_change = akeyless.models.last_config_change.LastConfigChange(
                        last_k8s_auths_change = akeyless.models.k8_s_auths_config_last_change.K8SAuthsConfigLastChange(
                            changed_k8s_auths_ids = [
                                '0'
                                ], 
                            created_k8s_auths_ids = [
                                '0'
                                ], 
                            deleted_k8s_auths_ids = [
                                '0'
                                ], ), 
                        last_migrations_change = akeyless.models.migrations_config_last_change.MigrationsConfigLastChange(
                            changed_migrations = [
                                '0'
                                ], 
                            created_migrations = [
                                '0'
                                ], 
                            deleted_migrations = [
                                '0'
                                ], ), ), 
                    last_status = akeyless.models.last_status_info.LastStatusInfo(
                        migrations_status = akeyless.models.migration_status.MigrationStatus(
                            last_messages = {
                                'key' : '0'
                                }, 
                            last_statuses = {
                                'key' : '0'
                                }, ), 
                        producers_errors = akeyless.models.producers_errors.producers_errors(), ), 
                    required_activity = akeyless.models.required_activity.RequiredActivity(
                        migrations_required_activity = {
                            'key' : True
                            }, ), 
                    update_stamp = 56, ), 
                total_hash = '0'
            )
        else :
            return GatewayUpdateK8SAuthConfigOutput(
        )

    def testGatewayUpdateK8SAuthConfigOutput(self):
        """Test GatewayUpdateK8SAuthConfigOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class K8SPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ca': 'list[int]',
        'client_cert': 'list[int]',
        'client_key': 'list[int]',
        'namespace': 'str',
        'password': 'str',
        'server': 'str',
        'skip_system': 'bool',
        'token': 'str',
        'username': 'str'
    }

    attribute_map = {
        'ca': 'ca',
        'client_cert': 'client_cert',
        'client_key': 'client_key',
        'namespace': 'namespace',
        'password': 'password',
        'server': 'server',
        'skip_system': 'skip_system',
        'token': 'token',
        'username': 'username'
    }

    def __init__(self, ca=None, client_cert=None, client_key=None, namespace=None, password=None, server=None, skip_system=None, token=None, username=None, local_vars_configuration=None):  # noqa: E501
        """K8SPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ca = None
        self._client_cert = None
        self._client_key = None
        self._namespace = None
        self._password = None
        self._server = None
        self._skip_system = None
        self._token = None
        self._username = None
        self.discriminator = None

        if ca is not None:
            self.ca = ca
        if client_cert is not None:
            self.client_cert = client_cert
        if client_key is not None:
            self.client_key = client_key
        if namespace is not None:
            self.namespace = namespace
        if password is not None:
            self.password = password
        if server is not None:
            self.server = server
        if skip_system is not None:
            self.skip_system = skip_system
        if token is not None:
            self.token = token
        if username is not None:
            self.username = username

    @property
    def ca(self):
        """Gets the ca of this K8SPayload.  # noqa: E501


        :return: The ca of this K8SPayload.  # noqa: E501
        :rtype: list[int]
        """
        return self._ca

    @ca.setter
    def ca(self, ca):
        """Sets the ca of this K8SPayload.


        :param ca: The ca of this K8SPayload.  # noqa: E501
        :type: list[int]
        """

        self._ca = ca

    @property
    def client_cert(self):
        """Gets the client_cert of this K8SPayload.  # noqa: E501


        :return: The client_cert of this K8SPayload.  # noqa: E501
        :rtype: list[int]
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this K8SPayload.


        :param client_cert: The client_cert of this K8SPayload.  # noqa: E501
        :type: list[int]
        """

        self._client_cert = client_cert

    @property
    def client_key(self):
        """Gets the client_key of this K8SPayload.  # noqa: E501


        :return: The client_key of this K8SPayload.  # noqa: E501
        :rtype: list[int]
        """
        return self._client_key

    @client_key.setter
    def client_key(self, client_key):
        """Sets the client_key of this K8SPayload.


        :param client_key: The client_key of this K8SPayload.  # noqa: E501
        :type: list[int]
        """

        self._client_key = client_key

    @property
    def namespace(self):
        """Gets the namespace of this K8SPayload.  # noqa: E501


        :return: The namespace of this K8SPayload.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this K8SPayload.


        :param namespace: The namespace of this K8SPayload.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def password(self):
        """Gets the password of this K8SPayload.  # noqa: E501


        :return: The password of this K8SPayload.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this K8SPayload.


        :param password: The password of this K8SPayload.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def server(self):
        """Gets the server of this K8SPayload.  # noqa: E501


        :return: The server of this K8SPayload.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this K8SPayload.


        :param server: The server of this K8SPayload.  # noqa: E501
        :type: str
        """

        self._server = server

    @property
    def skip_system(self):
        """Gets the skip_system of this K8SPayload.  # noqa: E501


        :return: The skip_system of this K8SPayload.  # noqa: E501
        :rtype: bool
        """
        return self._skip_system

    @skip_system.setter
    def skip_system(self, skip_system):
        """Sets the skip_system of this K8SPayload.


        :param skip_system: The skip_system of this K8SPayload.  # noqa: E501
        :type: bool
        """

        self._skip_system = skip_system

    @property
    def token(self):
        """Gets the token of this K8SPayload.  # noqa: E501


        :return: The token of this K8SPayload.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this K8SPayload.


        :param token: The token of this K8SPayload.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def username(self):
        """Gets the username of this K8SPayload.  # noqa: E501


        :return: The username of this K8SPayload.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this K8SPayload.


        :param username: The username of this K8SPayload.  # noqa: E501
        :type: str
        """

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, K8SPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, K8SPayload):
            return True

        return self.to_dict() != other.to_dict()
